@@ -6,7 +6,7 @@ require Tk::Photo;
 require DynaLoader;
 
 use vars qw($VERSION $XS_VERSION);
-$VERSION = '2.014_07';
+$VERSION = '2.01402'; # $Id: Lite.pm,v 1.4 2003/02/01 11:11:39 eserte Exp $
 
 @ISA = qw(DynaLoader);
 
@@ -35,14 +35,10 @@ This is a version of Tk::JPEG using a shared library.
 
 =head1 AUTHOR
 
-The original Tk::JPEG is by Nick Ing-Simmons E<lt>nick@ni-s.u-net.comE<gt>
+Nick Ing-Simmons E<lt>nick@ni-s.u-net.comE<gt>
 
 Stripped down to the lite version by Slaven Rezic E<lt>slaven@rezic.deE<gt>
 
-=head1 COPYRIGHT
-
-Copyright (C) 2002-2004,2007 Slaven Rezic. All rights reserved. This
-package is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
 =cut
+
+
